//---------------------------------------------------------------- -o--
// GalacticNumber.java
// 
// GalacticNumber manages the dynamic list of mappings between 
//   Galactic Numbers and Roman Numbers.
//
// THROWS GTException on error.
//
//
// CLASS METHODS--
//   mapFromRomanNumber
//   isNumber
//   asRomanNumber
//   clear
//
//
// DEPENDS UPON--
//   RomanNumber
//
//
// @version 0.1 
//

import java.util.*;



//-------------------------------------------------------------- -o--
public class GalacticNumber 
{                                                       
  private static HashMap<String, RomanNumber>  galacticNumberMap = null;

  final private static String  _CLASSNAME = "GalacticNumber";

  final static String  GALACTICNUMBER_ERROR = _CLASSNAME + " INPUT ERROR: ";


  //
  GalacticNumber()  { }  // EMPTY



  //-------------------------------------------------------------- -o--
  // Class methods.
  //

  //---------------- -o-
  public static void  mapFromRomanNumber(
                          String token, String romanNumber)  throws GTException
  { 
    if ((null == token) || (0 == token.length()))
    {
      throw new GTException(GALACTICNUMBER_ERROR +"Invalid token.");
    }

    if ((null == romanNumber) || (! RomanNumber.isNumber(romanNumber)))
    {
      throw new GTException(GALACTICNUMBER_ERROR +"Invalid Roman Number.");
    }


    //
    if (null == galacticNumberMap) {
      galacticNumberMap = new HashMap<String, RomanNumber>();
    }

    if (galacticNumberMap.containsKey(token)) {
      throw new GTException(
          GALACTICNUMBER_ERROR +"'"+ token +"' already exists.");
    }


    //
    RomanNumber  rn = RomanNumber.valueOf(romanNumber);
    galacticNumberMap.put(token, rn);

  }


  //---------------- -o-
  public static Boolean  isNumber(String token)
  {
    return galacticNumberMap.containsKey(token);
  }


  //---------------- -o-
  public static RomanNumber  asRomanNumber(String galacticNumber)
  {
    return galacticNumberMap.get(galacticNumber);
  }
 

  //---------------- -o-
  public static void  clear() 
  { 
    if (null != galacticNumberMap) {
      galacticNumberMap.clear(); 
      galacticNumberMap = null;
    }
  }


}  // public class GalacticNumber 

