//---------------------------------------------------------------- -o--
// GalacticNumeral.java
// 
// Converts a sequence GalacticNumbers into a RomanNumeral and conseqent
//   Arabic Numeral.
//
// THROWS GTException on error.
//
//
// INSTANCE METHODS--
//   GalacticNumeral
//   asArabicNumeral
//
//
// DEPENDS UPON--
//   GalacticNumber
//   RomanNumber
//   RomanNumeral
//
//
// @version 0.1 
//

import java.util.*;



//-------------------------------------------------------------- -o--
public class GalacticNumeral 
{                                                       
  private String        galacticNumeral  = null;
  private RomanNumeral  romanNumeral     = null;
  private Float         arabicNumeral    = null;

  final String  GALACTICNUMERAL_ERROR = getClass() + ": Invalid expression -- ";


  //-------------------------------------------------------------- -o--
  // Constructor.
  //

  //---------------- -o-
  GalacticNumeral(String galacticNumeralExpression)  throws GTException
  { 
    if ( (null == galacticNumeralExpression) 
           || (0 == galacticNumeralExpression.length()) )
    {
      throw new GTException(GALACTICNUMERAL_ERROR + "Malformed input.");
    }

    galacticNumeral = galacticNumeralExpression;


    //
    String[]  gnList           = galacticNumeralExpression.split("\\s");
    String    romanNumeralStr  = "";

    for (String token : gnList) 
    {
      RomanNumber rn = GalacticNumber.asRomanNumber(token);

      if (null == rn) {
	throw new GTException(GALACTICNUMERAL_ERROR 
	  + "Numeral contains Galactic Number that "
	    + "does not map to a Roman Number.");
      }

      romanNumeralStr += rn.toString();
    }


    //
    try {
      romanNumeral = new RomanNumeral(romanNumeralStr); 

    } catch (GTException e) {
      throw new GTException(GALACTICNUMERAL_ERROR 
	+ "Galactic Number sequence does not honor rules " 
	  + "of Roman Number order.");
    }

    arabicNumeral = romanNumeral.asArabicNumeral();

  } // GalacticNumeral



  //-------------------------------------------------------------- -o--
  // Instance methods.
  //

  //---------------- -o-
  Float asArabicNumeral()  { return arabicNumeral; }


}  // public class GalacticNumeral 

