//---------------------------------------------------------------- -o--
// RomanNumberTest.java 
// 
// Validate constructor of RomanNumber and distinction between elements
//   included and excluded by the emeration.
//
//
// TEST METHODS--
//   testIsNumber
//   testDetectSubtractFrom
//   testSubtractionVsAddition
//   testComparison
//
//
// @version 0.1
//

import java.lang.*;
import java.io.*;
import java.util.*;

import junit.framework.*;
import org.junit.*;
import org.apache.commons.io.*;
import org.hamcrest.*;



//----------------------------------------------------------------- -o--
public class RomanNumberTest extends TestCase
{
  //-------------------------------------------------------------- -o--
  // Test methods.
  //

  //------------------------------ -o-
  public void  testIsNumber()
  {
    assertTrue(
      "'Splat' IS NOT a Roman Number.", ! RomanNumber.isNumber("Splat") );

    assertTrue(
      "'L' IS a Roman Number.", RomanNumber.isNumber("L") );

  } // testIsNumber()


  //------------------------------ -o-
  @org.junit.Test
  public void  testDetectSubtractFrom()
  {
    RomanNumber rnM = RomanNumber.M,
                rnC = RomanNumber.C,
		rnX = RomanNumber.X;

    Boolean  mDidSubtract = false;


    //
    for (RomanNumber rn : RomanNumber.values()) 
    {
      if (rnM.maySubtractFrom(rn)) {
        mDidSubtract = true;
	break;
      }
    }

    assertTrue(
      "Roman Number M CANNOT SUBTRACT from ANY Roman Number.", 
      ! mDidSubtract );


    //
    assertTrue(
      "Roman Number C CAN SUBTRACT from M and D and NO OTHERS.",
      rnC.maySubtractFrom(RomanNumber.M) 
        && rnC.maySubtractFrom(RomanNumber.D) 
	  && (2 == rnC.subtracteeSet.size()) );


    //
    assertTrue(
      "Roman Number X CANNOT SUBTRACT from I.",
      ! rnX.maySubtractFrom(RomanNumber.I) );

  } // testDetectSubtractFrom()


  //------------------------------ -o-
  @org.junit.Test
  public void  testSubtractionVsAddition()
  {
    RomanNumber rnM = RomanNumber.M,
                rnC = RomanNumber.C,
                rnL = RomanNumber.L,
		rnX = RomanNumber.X;

    //
    rnC.addOccurence();

    assertTrue(
      "Roman Number C, having added to itself, CANNOT subtrace from others.",
      ! rnC.maySubtractFrom(rnM) );


    //
    rnX.setSubtracted();

    assertTrue(
      "Roman Number X, having subtracted, IS NOT available for other actions.",
      ! rnX.getIsAvailable() );

  } // testSubtractionVsAddition()


  //------------------------------ -o-
  @org.junit.Test
  public void  testComparison()
  {
    RomanNumber rnM = RomanNumber.M,
                rnC = RomanNumber.C,
                rnL = RomanNumber.L,
		rnX = RomanNumber.X;

    //
    assertTrue(
      "Roman Number X is less than Roman Number C.",
      rnX.isLessThan(rnC) );

    assertTrue(
      "Roman Number M is greater than Roman Number C.",
      rnM.isGreaterThan(rnC) );

  } // testComparison()


} // class RomanNumberTest

